This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[tree-ssa] tree-*.c: Fix comment typos.


Hi,

Committed as obvious.

Kazu Hirata

2004-01-15  Kazu Hirata  <kazu@cs.umass.edu>

	* tree-cfg.c: Fix comment typos.
	* tree-eh.c: Likewise.
	* tree-inline.c: Likewise.
	* tree-optimize.c: Likewise.
	* tree-ssa.c: Likewise.
	* tree-ssa-dom.c: Likewise.
	* tree-ssa-operands.c: Likewise.
	* tree-ssa-pre.c: Likewise.
	* tree-tailcall.c: Likewise.

Index: tree-cfg.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/Attic/tree-cfg.c,v
retrieving revision 1.1.4.254
diff -u -r1.1.4.254 tree-cfg.c
--- tree-cfg.c	14 Jan 2004 22:39:35 -0000	1.1.4.254
+++ tree-cfg.c	15 Jan 2004 06:38:04 -0000
@@ -235,7 +235,7 @@
       if (last == factored_computed_goto)
 	continue;
 
-      /* If the last statement is a compted goto, factor it.  */
+      /* If the last statement is a computed goto, factor it.  */
       if (computed_goto_p (last))
 	{
 	  tree assignment;
Index: tree-inline.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-inline.c,v
retrieving revision 1.26.2.76
diff -u -r1.26.2.76 tree-inline.c
--- tree-inline.c	9 Jan 2004 12:26:15 -0000	1.26.2.76
+++ tree-inline.c	15 Jan 2004 06:38:06 -0000
@@ -1244,7 +1244,7 @@
     case STRING_CST:
       *walk_subtrees = 0;
       return NULL;
-    /* Reconginze assignments of large structures and constructors of
+    /* Recognize assignments of large structures and constructors of
        big arrays.  */
     case INIT_EXPR:
     case TARGET_EXPR:
Index: tree-optimize.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-optimize.c,v
retrieving revision 1.1.4.108
diff -u -r1.1.4.108 tree-optimize.c
--- tree-optimize.c	14 Jan 2004 22:39:35 -0000	1.1.4.108
+++ tree-optimize.c	15 Jan 2004 06:38:06 -0000
@@ -561,7 +561,7 @@
       DECL_ARGUMENTS (fndecl) = cfun->saved_args;
 
       /* When not in unit-at-a-time mode, we must preserve out of line copy
-	 representing node before inlining.  Restore original ougoing edges
+	 representing node before inlining.  Restore original outgoing edges
 	 using clone we created earlier.  */
       if (!flag_unit_at_a_time)
 	{
Index: tree-ssa.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/Attic/tree-ssa.c,v
retrieving revision 1.1.4.185
diff -u -r1.1.4.185 tree-ssa.c
--- tree-ssa.c	14 Jan 2004 07:16:36 -0000	1.1.4.185
+++ tree-ssa.c	15 Jan 2004 06:38:08 -0000
@@ -2629,7 +2629,7 @@
 			 definition statement yet.  */
 		      new_name = make_ssa_name (result, phi);
 
-		      /* Now create the copy statemenet.  */
+		      /* Now create the copy statement.  */
 		      copy = build (MODIFY_EXPR, TREE_TYPE (arg),
 				    new_name, PHI_ARG_DEF (phi, i));
 
@@ -2707,7 +2707,7 @@
      tree->rtl expanders deal with.  */
   cfg_remove_useless_stmts ();
 
-  /* Remove unnecesary variables.  */
+  /* Remove unnecessary variables.  */
   remove_useless_vars ();
 
   /* Flush out flow graph and SSA data.  */
@@ -3240,7 +3240,7 @@
  
      Experimentation showed that once we get more than 8 phi vector
      entries that moving to a fully-pruned implementation is comparable
-     to semi-pruned.  32 showed up as the threshhold which maximized
+     to semi-pruned.  32 showed up as the threshold which maximized
      overall compile-time performance. 
 
      Note that as this number gets larger, the potential for the
Index: tree-ssa-dom.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/Attic/tree-ssa-dom.c,v
retrieving revision 1.1.2.110
diff -u -r1.1.2.110 tree-ssa-dom.c
--- tree-ssa-dom.c	14 Jan 2004 07:16:36 -0000	1.1.2.110
+++ tree-ssa-dom.c	15 Jan 2004 06:38:09 -0000
@@ -570,7 +570,7 @@
       /* Do not forward entry edges into the loop.  In the case loop
 	 has multiple entry edges we may end up in constructing irreducible
 	 region.  
-	 ??? We may consider forwarding the edges in the case all incomming
+	 ??? We may consider forwarding the edges in the case all incoming
 	 edges forward to the same destination block.  */
       if (!e->flags & EDGE_DFS_BACK)
 	{
@@ -2440,7 +2440,7 @@
   if (slot)
     return boolean_false_node;
 
-  /* Finaly try to find the expression in the main expression hash table.  */
+  /* Finally try to find the expression in the main expression hash table.  */
   slot = htab_find_slot (avail_exprs, stmt, (insert ? INSERT : NO_INSERT));
   if (slot == NULL)
     return NULL_TREE;
Index: tree-ssa-operands.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/Attic/tree-ssa-operands.c,v
retrieving revision 1.1.2.4
diff -u -r1.1.2.4 tree-ssa-operands.c
--- tree-ssa-operands.c	7 Jan 2004 23:44:15 -0000	1.1.2.4
+++ tree-ssa-operands.c	15 Jan 2004 06:38:10 -0000
@@ -103,7 +103,7 @@
   return vec;
 #endif
 }
-/* Return a vector of contguous memory of a specified size.  */
+/* Return a vector of contiguous memory of a specified size.  */
 
 
 static inline void
Index: tree-ssa-pre.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/Attic/tree-ssa-pre.c,v
retrieving revision 1.1.4.122
diff -u -r1.1.4.122 tree-ssa-pre.c
--- tree-ssa-pre.c	14 Jan 2004 07:16:36 -0000	1.1.4.122
+++ tree-ssa-pre.c	15 Jan 2004 06:38:11 -0000
@@ -533,7 +533,7 @@
      || a2 != a3)
      return false
 
-     Or, in english,  if either the assigned-to variable in
+     Or, in English,  if either the assigned-to variable in
      the injury is different from the first variable in the
      expression, or the incremented variable is different from the
      first variable in the expression, punt.
Index: tree-tailcall.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/Attic/tree-tailcall.c,v
retrieving revision 1.1.2.16
diff -u -r1.1.2.16 tree-tailcall.c
--- tree-tailcall.c	14 Jan 2004 07:16:36 -0000	1.1.2.16
+++ tree-tailcall.c	15 Jan 2004 06:38:11 -0000
@@ -211,7 +211,7 @@
       break;
     }
 
-  /* Unless we found soumething that stops the search, recurse to the
+  /* Unless we found something that stops the search, recurse to the
      predecessors.  */
   if (!found)
     {


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: tree-eh.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/Attic/tree-eh.c,v
retrieving revision 1.1.2.22
diff -u -r1.1.2.22 tree-eh.c
--- tree-eh.c	12 Jan 2004 23:39:33 -0000	1.1.2.22
+++ tree-eh.c	15 Jan 2004 06:38:04 -0000
@@ -850,7 +850,7 @@
 
 /* A subroutine of lower_try_finally.  We have determined that there is
    no fallthru edge out of the finally block.  This means that there is
-   no outgoing edge corresponding to any incomming edge.  Restructure the
+   no outgoing edge corresponding to any incoming edge.  Restructure the
    try_finally node for this special case.  */
 
 static void
@@ -1158,7 +1158,7 @@
 
   append_to_statement_list (finally, tf->top_p);
 
   /* Redirect each incomming goto edge.  */
   q = tf->goto_queue;
   qe = q + tf->goto_queue_active;
   j = last_case_index + tf->may_return;
@@ -1215,7 +1215,7 @@
    First, if this is Java, then the finally block contains code
    written by the user.  It has line numbers associated with it,
    so duplicating the block means it's difficult to set a breakpoint.
-   Since controling code generation via -g is verboten, we simply
+   Since controlling code generation via -g is verboten, we simply
    never duplicate code without optimization.
 
    Second, we'd like to prevent egregious code growth.  One way to
@@ -1158,7 +1158,7 @@
   append_to_statement_list (finally, tf->top_p);
 
-  /* Redirect each incomming goto edge.  */
+  /* Redirect each incoming goto edge.  */
   q = tf->goto_queue;
   qe = q + tf->goto_queue_active;